@@ -18,7 +18,10 @@ pub struct Publish {
 pub struct PublishAck;
 
 impl Publish {
-    pub(crate) fn new(publish: codec::Publish) -> Self {
+    /// Create a new `Publish` message from a PUBLISH
+    /// packet
+    #[doc(hidden)]
+    pub fn new(publish: codec::Publish) -> Self {
         Self { topic: Path::new(publish.topic.clone()), publish }
     }
 
