@@ -2,9 +2,9 @@ use std::{future::Future, num::NonZeroU16, num::NonZeroU32, rc::Rc, time::Durati
 
 use ntex::codec::{AsyncRead, AsyncWrite};
 use ntex::connect::{self, Address, Connect, Connector};
-use ntex::rt::time::delay_for;
 use ntex::service::Service;
-use ntex::util::{select, ByteString, Bytes, Either};
+use ntex::time::{timeout, Seconds};
+use ntex::util::{select, ByteString, Bytes, Either, PoolId};
 
 #[cfg(feature = "openssl")]
 use ntex::connect::openssl::{OpensslConnector, SslConnector};
@@ -21,8 +21,8 @@ pub struct MqttConnector<A, T> {
     address: A,
     connector: T,
     pkt: codec::Connect,
-    handshake_timeout: u16,
-    disconnect_timeout: u16,
+    handshake_timeout: Seconds,
+    disconnect_timeout: Seconds,
     pool: Rc<MqttSinkPool>,
 }
 
@@ -37,8 +37,8 @@ where
             address,
             pkt: codec::Connect::default(),
             connector: Connector::default(),
-            handshake_timeout: 0,
-            disconnect_timeout: 3000,
+            handshake_timeout: Seconds::ZERO,
+            disconnect_timeout: Seconds(3),
             pool: Rc::new(MqttSinkPool::default()),
         }
     }
@@ -71,8 +71,8 @@ where
     /// A time interval measured in seconds.
     ///
     /// keep-alive is set to 30 seconds by default.
-    pub fn keep_alive(mut self, val: u16) -> Self {
-        self.pkt.keep_alive = val;
+    pub fn keep_alive(mut self, val: Seconds) -> Self {
+        self.pkt.keep_alive = val.seconds() as u16;
         self
     }
 
@@ -154,16 +154,16 @@ where
         self
     }
 
-    /// Set handshake timeout in milliseconds.
+    /// Set handshake timeout.
     ///
     /// Handshake includes `connect` packet and response `connect-ack`.
     /// By default handshake timeuot is disabled.
-    pub fn handshake_timeout(mut self, timeout: u16) -> Self {
-        self.handshake_timeout = timeout as u16;
+    pub fn handshake_timeout(mut self, timeout: Seconds) -> Self {
+        self.handshake_timeout = timeout;
         self
     }
 
-    /// Set client connection disconnect timeout in milliseconds.
+    /// Set client connection disconnect timeout.
     ///
     /// Defines a timeout for disconnect connection. If a disconnect procedure does not complete
     /// within this time, the connection get dropped.
@@ -171,8 +171,17 @@ where
     /// To disable timeout set value to 0.
     ///
     /// By default disconnect timeout is set to 3 seconds.
-    pub fn disconnect_timeout(mut self, timeout: u16) -> Self {
-        self.disconnect_timeout = timeout as u16;
+    pub fn disconnect_timeout(mut self, timeout: Seconds) -> Self {
+        self.disconnect_timeout = timeout;
+        self
+    }
+
+    /// Set memory pool.
+    ///
+    /// Use specified memory pool for memory allocations. By default P5
+    /// memory pool is used.
+    pub fn memory_pool(self, id: PoolId) -> Self {
+        self.pool.pool.set(id.pool_ref());
         self
     }
 
@@ -222,16 +231,12 @@ where
 
     /// Connect to mqtt server
     pub fn connect(&self) -> impl Future<Output = Result<Client<T::Response>, ClientError>> {
-        if self.handshake_timeout > 0 {
-            let fut = select(
-                delay_for(Duration::from_millis(self.handshake_timeout as u64)),
-                self._connect(),
-            );
+        if self.handshake_timeout.non_zero() {
+            let fut = timeout(self.handshake_timeout, self._connect());
             Either::Left(async move {
-                let result = fut.await;
-                match result {
-                    Either::Left(_) => Err(ClientError::HandshakeTimeout),
-                    Either::Right(res) => res.map_err(From::from),
+                match fut.await {
+                    Ok(res) => res.map_err(From::from),
+                    Err(_) => Err(ClientError::HandshakeTimeout),
                 }
             })
         } else {
@@ -250,10 +255,10 @@ where
 
         async move {
             let mut io = fut.await?;
-            let state = State::new();
+            let state = State::with_memory_pool(pool.pool.get());
             let codec = codec::Codec::new().max_inbound_size(max_packet_size);
 
-            state.send(&mut io, &codec, codec::Packet::Connect(pkt)).await?;
+            state.send(&mut io, &codec, codec::Packet::Connect(Box::new(pkt))).await?;
 
             let packet = state
                 .next(&mut io, &codec)
@@ -285,7 +290,7 @@ where
                             shared,
                             pkt,
                             max_receive,
-                            keep_alive,
+                            Seconds(keep_alive),
                             disconnect_timeout,
                         ))
                     } else {
