@@ -3,8 +3,8 @@ use std::{convert::TryFrom, num::NonZeroU16, time::Duration};
 
 use futures::{future::ok, FutureExt, SinkExt, StreamExt};
 use ntex::codec::Framed;
-use ntex::rt::time::sleep;
 use ntex::server;
+use ntex::time::sleep;
 use ntex::util::{poll_fn, ByteString, Bytes};
 
 use ntex_mqtt::v5::{
@@ -73,8 +73,8 @@ async fn test_simple() -> std::io::Result<()> {
 async fn test_disconnect() -> std::io::Result<()> {
     let srv = server::test_server(|| {
         MqttServer::new(handshake)
-            .publish(ntex::fn_factory_with_config(|session: Session<St>| {
-                ok::<_, TestError>(ntex::fn_service(move |p: Publish| {
+            .publish(ntex::service::fn_factory_with_config(|session: Session<St>| {
+                ok::<_, TestError>(ntex::service::fn_service(move |p: Publish| {
                     session.sink().close();
                     async move {
                         sleep(Duration::from_millis(100)).await;
@@ -104,8 +104,8 @@ async fn test_disconnect() -> std::io::Result<()> {
 async fn test_disconnect_with_reason() -> std::io::Result<()> {
     let srv = server::test_server(|| {
         MqttServer::new(handshake)
-            .publish(ntex::fn_factory_with_config(|session: Session<St>| {
-                ok::<_, TestError>(ntex::fn_service(move |p: Publish| {
+            .publish(ntex::service::fn_factory_with_config(|session: Session<St>| {
+                ok::<_, TestError>(ntex::service::fn_service(move |p: Publish| {
                     let pkt = codec::Disconnect {
                         reason_code: codec::DisconnectReasonCode::ServerMoved,
                         ..Default::default()
@@ -160,7 +160,7 @@ async fn test_ping() -> std::io::Result<()> {
     let io = srv.connect().await.unwrap();
     let mut framed = Framed::new(io, codec::Codec::new());
     framed
-        .send(codec::Packet::Connect(codec::Connect::default().client_id("user")))
+        .send(codec::Packet::Connect(Box::new(codec::Connect::default().client_id("user"))))
         .await
         .unwrap();
     let _ = framed.next().await.unwrap().unwrap();
@@ -197,7 +197,7 @@ async fn test_ack_order() -> std::io::Result<()> {
     let io = srv.connect().await.unwrap();
     let mut framed = Framed::new(io, codec::Codec::default());
     framed
-        .send(codec::Packet::Connect(codec::Connect::default().client_id("user")))
+        .send(codec::Packet::Connect(Box::new(codec::Connect::default().client_id("user"))))
         .await
         .unwrap();
     let _ = framed.next().await.unwrap().unwrap();
@@ -268,9 +268,9 @@ async fn test_dups() {
     let io = srv.connect().await.unwrap();
     let mut framed = Framed::new(io, codec::Codec::default());
     framed
-        .send(codec::Packet::Connect(
+        .send(codec::Packet::Connect(Box::new(
             codec::Connect::default().client_id("user").receive_max(2),
-        ))
+        )))
         .await
         .unwrap();
     let _ = framed.next().await.unwrap().unwrap();
@@ -385,19 +385,19 @@ async fn test_max_receive() {
     let mut framed = Framed::new(io, codec::Codec::default());
 
     framed
-        .send(codec::Packet::Connect(codec::Connect::default().client_id("user")))
+        .send(codec::Packet::Connect(Box::new(codec::Connect::default().client_id("user"))))
         .await
         .unwrap();
     let ack = framed.next().await.unwrap().unwrap();
     assert_eq!(
         ack,
-        codec::Packet::ConnectAck(codec::ConnectAck {
+        codec::Packet::ConnectAck(Box::new(codec::ConnectAck {
             receive_max: Some(NonZeroU16::new(1).unwrap()),
             max_qos: Some(codec::QoS::AtLeastOnce),
             reason_code: codec::ConnectAckReason::Success,
             topic_alias_max: 32,
             ..Default::default()
-        })
+        }))
     );
 
     framed
@@ -657,7 +657,7 @@ async fn test_suback_with_reason() -> std::io::Result<()> {
     let io = srv.connect().await.unwrap();
     let mut framed = Framed::new(io, codec::Codec::new());
     framed
-        .send(codec::Packet::Connect(codec::Connect::default().client_id("user")))
+        .send(codec::Packet::Connect(Box::new(codec::Connect::default().client_id("user"))))
         .await
         .unwrap();
     let _ = framed.next().await.unwrap().unwrap();
@@ -720,7 +720,9 @@ async fn test_handle_incoming() -> std::io::Result<()> {
 
     let io = srv.connect().await.unwrap();
     let mut framed = Framed::new(io, codec::Codec::default());
-    framed.write(codec::Packet::Connect(codec::Connect::default().client_id("user"))).unwrap();
+    framed
+        .write(codec::Packet::Connect(Box::new(codec::Connect::default().client_id("user"))))
+        .unwrap();
     framed.write(pkt_publish().into()).unwrap();
     framed
         .write(codec::Packet::Disconnect(codec::Disconnect {
